@@ -13,7 +13,7 @@ class TemperatureSensor(ISensor):
 
     def get_values(self):
         data = self._get_data()
-        temperature = float(data[0])
+        temperature = float(data)
         self.entries += 1
         self.cum_sum += temperature
         temperature_avg = self.cum_sum / self.entries
