@@ -3,7 +3,7 @@ from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDr
 from flockai.models.probes.flockai_probe import FlockAIProbe
 from flockai.models.devices.device_enums import EnableableDevice, NonEnableableDevice
 import time
-
+import json
 
 class KeyboardMavic2DJI(KeyboardControlledDrone):
     """
@@ -47,12 +47,20 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         return self.energy_model.processing_energy.calculate(cpu_time_active=cpu_time, flight_time=flight_time, io_time=io_time)
 
     def get_communication_energy(self, comm_transmit_time, comm_receive_time):
+
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
         flight_time = probe_alive_time.get_val()
         return self.energy_model.communication_energy.calculate(transmit_time=comm_transmit_time, receive_time=comm_receive_time, idle_time=flight_time-(comm_transmit_time + comm_receive_time))
 
+    def get_motor_energy(self):
+        probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
+        flight_time = probe_alive_time.get_val()
+        return self.energy_model.motor_energy.calculate(hovering_time=flight_time)
+
     def run(self):
         # Wait a second before starting
+
+
         while self.step(self.basic_time_step) != -1:
             if self.getTime() > 1:
                 break
@@ -72,36 +80,46 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         comm_receive_time = 0
 
         while self.step(self.basic_time_step) != -1:
+
+            if self.getTime() > 60:
+                break
+
             self.blink_led_lights(led_devices)
             self.actuate()
 
             # Drone sends data specified by the user to the base station if ML is not running on board
             # TODO:
-            t1 = time.time()
-            self.send_msg(msg="test", emitter_devices=emitter_devices)
-            t2 = time.time()
-            comm_transmit_time += t2 - t1
-            t1 = time.time()
-            received_messages = self.receive_msgs(receiver_devices=receiver_devices)
-            t2 = time.time()
-            comm_receive_time += t2 - t1
+            # t1 = time.time()
+            # self.send_msg(msg="test", emitter_devices=emitter_devices)
+            # t2 = time.time()
+            # comm_transmit_time += t2 - t1
+            # t1 = time.time()
+            # received_messages = self.receive_msgs(receiver_devices=receiver_devices)
+            # t2 = time.time()
+            # comm_receive_time += t2 - t1
 
             # Execute prediction pipeline step
             if self.model is not None:
                 prediction = self.model.predict()
-                # if prediction is not None:
-                #     print(prediction)
-
+                if prediction is not None:
+                    print(prediction)
             # Get energy values on each cycle
             energy = {**self.get_processing_energy(),
-                      **self.get_communication_energy(comm_transmit_time=comm_transmit_time, comm_receive_time=comm_receive_time)}
-            energy['total_energy'] = energy['e_proc'] + energy['e_comm']
+                      **self.get_communication_energy(comm_transmit_time=comm_transmit_time, comm_receive_time=comm_receive_time),
+                      **self.get_motor_energy(), 'simulation_time_s': self.getTime()}
+
+            energy['total_energy'] = energy['e_proc'] + energy['e_comm'] + energy['e_motor']
 
             # Update battery values
             self.battery.remaining_energy_percentage = 1.0 - (energy['total_energy'] / self.battery.energy_capacity)
 
+            if self.getTime() % 5.0 != 0.0:
+                continue
+
             # Update log data every 5 minutes with energy values
-            print(energy, f'{self.battery.remaining_energy_percentage * 100}% battery remaining')
+            print(energy, f'\n{self.battery.remaining_energy_percentage * 100}% battery remaining')
+            with open('logs/ML_on_drone.json', 'w') as logfile:
+                json.dump(energy, logfile)
 
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
